@@ -23,16 +23,16 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
         # - on_refresh_token
         # - before_token_refresh, expected to return a dictionary to be passed
         #   on to `_refresh_tokens` as keyword arguments
-        self._callback_on_token_refresh = kwargs.get('on_token_refresh', None)
+        self._callback_on_token_refresh = kwargs.get("on_token_refresh", None)
         if self._callback_on_token_refresh is not None:
             assert callable(self._callback_on_token_refresh)
 
-        self._before_token_refresh = kwargs.get('before_token_refresh', None)
+        self._before_token_refresh = kwargs.get("before_token_refresh", None)
         if self._before_token_refresh is not None:
             assert callable(self._before_token_refresh)
 
         # extract the supported helper methods
-        self._helper_get_refresh_token = kwargs.get('get_refresh_token', None)
+        self._helper_get_refresh_token = kwargs.get("get_refresh_token", None)
         if self._helper_get_refresh_token is not None:
             assert callable(self._helper_get_refresh_token)
 
@@ -45,14 +45,15 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
 
         # call parent function
         super(PlatformSquirroClient, self)._on_token_refresh(
-            access_token, refresh_token)
+            access_token, refresh_token
+        )
 
         # safely invoke callback
         try:
             if self._callback_on_token_refresh:
                 self._callback_on_token_refresh(access_token, refresh_token)
         except Exception as ex:
-            log.debug('error during callback invocation: %r', ex)
+            log.debug("error during callback invocation: %r", ex)
             raise
 
     def _refresh_tokens(self):
@@ -74,10 +75,10 @@ class PlatformSquirroClient(SquirroClient, UserApiMixin, TopicApiMixin):
         try:
             if self._helper_get_refresh_token:
                 token = self._helper_get_refresh_token()
-                log.debug('helper invocation yielded refresh token %r', token)
+                log.debug("helper invocation yielded refresh token %r", token)
                 self.refresh_token = token
         except Exception as ex:
-            log.debug('error during helper invocation: %r', ex)
+            log.debug("error during helper invocation: %r", ex)
             raise
 
         # call parent function again
