@@ -1,9 +1,4 @@
 """Sends items to Squirro."""
-from __future__ import absolute_import, division, print_function
-from future import standard_library
-
-standard_library.install_aliases()  # noqa
-
 import copy
 import logging
 import math
@@ -20,7 +15,6 @@ from .base import SquirroClient
 from .exceptions import NotFoundError
 from .util import deprecation
 
-
 try:
     import ujson as json
 except ImportError:
