@@ -1,19 +1,15 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import json
 import logging
+from builtins import object
 
 from squirro_client.util import deprecation
-from builtins import object
 
 log = logging.getLogger(__name__)
 
 
 class DashboardsMixin(object):
-
     def get_dashboards(self, project_id):
         """Return all dashboard for the given project.
 
@@ -36,12 +32,12 @@ class DashboardsMixin(object):
                             u'title': u'Search Results',
                             u'type': u'Search'}]}]
         """
-        url = '%(ep)s/v0/%(tenant)s/projects/%(project_id)s/dashboards' % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
+        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/dashboards" % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
         }
-        res = self._perform_request('get', url)
+        res = self._perform_request("get", url)
         return self._process_response(res)
 
     def get_dashboard(self, project_id, dashboard_id):
@@ -69,23 +65,41 @@ class DashboardsMixin(object):
                            u'title': u'Search Results',
                            u'type': u'Search'}]}
         """
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s') % {
-                   'ep': self.topic_api_url,
-                   'tenant': self.tenant,
-                   'project_id': project_id,
-                   'dashboard_id': dashboard_id,
-               }
-        res = self._perform_request('get', url)
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
+        res = self._perform_request("get", url)
         return self._process_response(res)
 
-    def new_dashboard(self, project_id, title, search=None, type=None,
-                      column_count=None, row_height=None, theme_id=None,
-                      hide_title=None, reset_placement=None, sections=None,
-                      panels=None, sidepanel=None, mobileSections=None,
-                      loaders=None, desyncFromDesktop=None, dashboard_id=None,
-                      restricted=None, store=None, transparent=None,
-                      layout=None):
+    def new_dashboard(
+        self,
+        project_id,
+        title,
+        search=None,
+        type=None,
+        column_count=None,
+        row_height=None,
+        theme_id=None,
+        hide_title=None,
+        reset_placement=None,
+        sections=None,
+        panels=None,
+        sidepanel=None,
+        mobileSections=None,
+        loaders=None,
+        desyncFromDesktop=None,
+        dashboard_id=None,
+        restricted=None,
+        default_store=None,
+        transparent=None,
+        layout=None,
+    ):
         """Create a new dashboard.
 
         :param project_id: Project identifier
@@ -114,7 +128,8 @@ class DashboardsMixin(object):
             be 22 characters. Useful when exporting and importing projects
             across multiple Squirro servers.
         :param restricted: Boolean, whether the dashboard has permissions set
-        :param store: Dict, dashboard store state to be saved with the dashboard
+        :param default_store: Dict, dashboard default store state to be saved
+            with the dashboard
         :param transparent: Boolean, whether the dashboard uses a transparent
             background or not
         :param layout: Dict, Dashboard layout configuration
@@ -131,7 +146,7 @@ class DashboardsMixin(object):
                  u'row_height': 55,
                  u'search': None,
                  u'panels': [],
-                 u'store': {},
+                 u'default_store': {},
                  u'desyncFromDesktop': False,
                  u'sidepanel': False,
                  u'transparent': False,
@@ -284,59 +299,76 @@ class DashboardsMixin(object):
                 }
         """
         if mobileSections:
-            msg = 'MobileSections are deprecated please use panels instead'
+            msg = "MobileSections are deprecated please use panels instead"
             deprecation(msg)
         if sections:
-            msg = 'Sections are deprecated please use panels instead'
+            msg = "Sections are deprecated please use panels instead"
             deprecation(msg)
 
-        url = '%(ep)s/v0/%(tenant)s/projects/%(project_id)s/dashboards' % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
+        url = "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/dashboards" % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
         }
         data = {
-            'title': title,
-            'search': search,
-            'type': type,
-            'panels': panels,
-            'desyncFromDesktop': desyncFromDesktop,
-            'sidepanel': sidepanel,
-            'loaders': loaders,
-            'transparent': transparent,
-            'layout': layout,
+            "title": title,
+            "search": search,
+            "type": type,
+            "panels": panels,
+            "desyncFromDesktop": desyncFromDesktop,
+            "sidepanel": sidepanel,
+            "loaders": loaders,
+            "transparent": transparent,
+            "layout": layout,
         }
         if dashboard_id:
-            data['dashboard_id'] = dashboard_id
+            data["dashboard_id"] = dashboard_id
 
         if column_count:
-            data['column_count'] = column_count
+            data["column_count"] = column_count
         if row_height:
-            data['row_height'] = row_height
+            data["row_height"] = row_height
         if theme_id:
-            data['theme_id'] = theme_id
+            data["theme_id"] = theme_id
         if hide_title:
-            data['hide_title'] = hide_title
+            data["hide_title"] = hide_title
         if reset_placement:
-            data['reset_placement'] = reset_placement
+            data["reset_placement"] = reset_placement
         if restricted:
-            data['restricted'] = restricted
-        if store:
-            data['store'] = store
+            data["restricted"] = restricted
+        if default_store:
+            data["default_store"] = default_store
 
-        headers = {'Content-Type': 'application/json'}
-        res = self._perform_request(
-            'post', url, data=json.dumps(data), headers=headers)
+        headers = {"Content-Type": "application/json"}
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201])
 
-    def modify_dashboard(self, project_id, dashboard_id, title=None,
-                         search=None, type=None, column_count=None,
-                         row_height=None, theme_id=None, hide_title=None,
-                         reset_placement=None, sections=None, panels=None,
-                         sidepanel=None, loaders=None, widgets=None,
-                         mobileSections=None, desyncFromDesktop=None,
-                         restricted=None, store=None, master=None,
-                         transparent=None, layout=None):
+    def modify_dashboard(
+        self,
+        project_id,
+        dashboard_id,
+        title=None,
+        search=None,
+        type=None,
+        column_count=None,
+        row_height=None,
+        theme_id=None,
+        hide_title=None,
+        reset_placement=None,
+        sections=None,
+        panels=None,
+        sidepanel=None,
+        loaders=None,
+        widgets=None,
+        mobileSections=None,
+        desyncFromDesktop=None,
+        restricted=None,
+        default_store=None,
+        master=None,
+        role=None,
+        transparent=None,
+        layout=None,
+    ):
         """Update a dashboard.
 
         :param project_id: Project identifier
@@ -361,10 +393,11 @@ class DashboardsMixin(object):
         :param desyncFromDesktop: Boolean, whether to sync the mobile content
             to desktop version or not
         :param restricted: Boolean, whether the dashboard has permissions set
-        :param store: Dict, dashboard store state to be saved with the dashboard
-        :param master: Bool, Whether this dashboard should be the new master
-            dashboard or not. Doing this operation will automatically reset the
-            master flag of the previous master dashboard to False
+        :param default_store: Dict, dashboard default store state to be saved
+            with the dashboard
+        :param master: Deprecated, use `role` instead
+        :param role: str, Defines the role of a dashboard.
+            Valid values are "search" & "normal"
         :param transparent: Boolean, whether the dashboard uses a transparent
             background or not
         :param layout: Dict, Dashboard layout configuration
@@ -378,51 +411,59 @@ class DashboardsMixin(object):
             ...                         search={'query': 'Demo'})
         """
         if mobileSections:
-            msg = 'MobileSections are deprecated please use panels instead'
+            msg = "MobileSections are deprecated please use panels instead"
             deprecation(msg)
         if sections:
-            msg = 'Sections are deprecated please use panels instead'
+            msg = "Sections are deprecated please use panels instead"
             deprecation(msg)
         if widgets:
-            msg = 'Widgets are deprecated please use panels instead'
+            msg = "Widgets are deprecated please use panels instead"
+            deprecation(msg)
+        if master is not None:
+            msg = "`master` parameter is deprecated, please use `role` instead"
             deprecation(msg)
 
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s') % {
-                   'ep': self.topic_api_url,
-                   'tenant': self.tenant,
-                   'project_id': project_id,
-                   'dashboard_id': dashboard_id,
-               }
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
         data = {
-            'title': title,
-            'search': search,
-            'type': type,
-            'column_count': column_count,
-            'row_height': row_height,
-            'theme_id': theme_id,
-            'hide_title': hide_title,
-            'reset_placement': reset_placement,
-            'panels': panels,
-            'desyncFromDesktop': desyncFromDesktop,
-            'sidepanel': sidepanel,
-            'loaders': loaders,
-            'restricted': restricted,
-            'store': store,
-            'transparent': transparent,
-            'layout': layout,
+            "title": title,
+            "search": search,
+            "type": type,
+            "column_count": column_count,
+            "row_height": row_height,
+            "theme_id": theme_id,
+            "hide_title": hide_title,
+            "reset_placement": reset_placement,
+            "panels": panels,
+            "desyncFromDesktop": desyncFromDesktop,
+            "sidepanel": sidepanel,
+            "loaders": loaders,
+            "restricted": restricted,
+            "default_store": default_store,
+            "transparent": transparent,
+            "layout": layout,
         }
 
         if master is not None:
-            data['master'] = master
+            data["master"] = master
+        if role is not None:
+            data["role"] = role
 
         post_data = {}
         for key, value in data.items():
             if value is not None:
                 post_data[key] = value
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
         res = self._perform_request(
-            'put', url, data=json.dumps(post_data), headers=headers)
+            "put", url, data=json.dumps(post_data), headers=headers
+        )
         return self._process_response(res)
 
     def move_dashboard(self, project_id, dashboard_id, after):
@@ -442,16 +483,19 @@ class DashboardsMixin(object):
             ...                       'Ue1OceLkQlyz21wpPqml9Q',
             ...                       'nJXpKUSERmSgQRjxX7LrZw')
         """
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s/move') % {
-                   'ep': self.topic_api_url,
-                   'tenant': self.tenant,
-                   'project_id': project_id,
-                   'dashboard_id': dashboard_id,
-               }
-        headers = {'Content-Type': 'application/json'}
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s/move"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
+        headers = {"Content-Type": "application/json"}
         res = self._perform_request(
-            'post', url, data=json.dumps({'after': after}), headers=headers)
+            "post", url, data=json.dumps({"after": after}), headers=headers
+        )
         return self._process_response(res, [204])
 
     def delete_dashboard(self, project_id, dashboard_id):
@@ -467,14 +511,16 @@ class DashboardsMixin(object):
             >>> client.delete_dashboard('2aEVClLRRA-vCCIvnuEAvQ',
             ...                         'Ue1OceLkQlyz21wpPqml9Q')
         """
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s') % {
-                   'ep': self.topic_api_url,
-                   'tenant': self.tenant,
-                   'project_id': project_id,
-                   'dashboard_id': dashboard_id,
-               }
-        res = self._perform_request('delete', url)
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
     def get_dashboard_permissions(self, project_id, dashboard_id):
@@ -517,18 +563,19 @@ class DashboardsMixin(object):
                 'is_default': True
             }
         """
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s/permissions') % {
-                   'ep': self.topic_api_url,
-                   'tenant': self.tenant,
-                   'project_id': project_id,
-                   'dashboard_id': dashboard_id,
-               }
-        res = self._perform_request('get', url)
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s/permissions"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
+        res = self._perform_request("get", url)
         return self._process_response(res)
 
-    def create_dashboard_permissions(self, project_id, dashboard_id,
-                                     permissions_list):
+    def create_dashboard_permissions(self, project_id, dashboard_id, permissions_list):
         """(re)Create dashboard permissions for a specific project.
 
         :param project_id: Project identifier
@@ -564,17 +611,19 @@ class DashboardsMixin(object):
                 ]
             }
         """
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s/permissions') % {
-                  'ep': self.topic_api_url,
-                  'tenant': self.tenant,
-                  'project_id': project_id,
-                  'dashboard_id': dashboard_id,
-              }
-        headers = {'Content-Type': 'application/json'}
-        res = self._perform_request('post', url,
-                                    data=json.dumps(permissions_list),
-                                    headers=headers)
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s/permissions"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
+        headers = {"Content-Type": "application/json"}
+        res = self._perform_request(
+            "post", url, data=json.dumps(permissions_list), headers=headers
+        )
         return self._process_response(res)
 
     def set_default_dashboard_permissions(self, project_id, dashboard_id):
@@ -589,13 +638,13 @@ class DashboardsMixin(object):
             permissions in place
         """
         res_get = self.get_dashboard_permissions(project_id, dashboard_id)
-        is_default = res_get.get('is_default')
+        is_default = res_get.get("is_default")
         if not is_default:
-            msg = 'Dashboard already has permissions'
+            msg = "Dashboard already has permissions"
             log.warning(msg)
-            return {'error': msg}
+            return {"error": msg}
 
-        permissions = res_get.get('permissions')
+        permissions = res_get.get("permissions")
         res_post = self.create_dashboard_permissions(
             project_id, dashboard_id, permissions
         )
@@ -616,12 +665,14 @@ class DashboardsMixin(object):
             >>> client.delete_dashboard_permissions('2aEVClLRRA-vCCIvnuEAvQ',
             ...                 'G0Tm2SQcTqu2d4GvfyrsMg')
         """
-        url = ('%(ep)s/v0/%(tenant)s/projects/%(project_id)s/'
-               'dashboards/%(dashboard_id)s/permissions') % {
-                  'ep': self.topic_api_url,
-                  'tenant': self.tenant,
-                  'project_id': project_id,
-                  'dashboard_id': dashboard_id,
-              }
-        res = self._perform_request('delete', url)
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/"
+            "dashboards/%(dashboard_id)s/permissions"
+        ) % {
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "dashboard_id": dashboard_id,
+        }
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
