@@ -1,16 +1,8 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
-from future import standard_library
-
-standard_library.install_aliases()  # noqa
-
-from builtins import object
 import json
-import urllib.request
-import urllib.parse
 import urllib.error
+import urllib.parse
+import urllib.request
+from builtins import object
 
 
 class EnrichmentsMixin(object):
