@@ -1,7 +1,3 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
 import os
 from builtins import object
 
@@ -36,17 +32,21 @@ class GlobalTempMixin(object):
         res = self._perform_request("post", url, files={"file": data}, headers=headers)
         return self._process_response(res, [201])
 
-    def get_tempfile(self, filename):
+    def get_tempfile(self, filename, file_type=None):
         """Returns the content of the temp file with the name `filename`.
 
         :param filename: File name
+        :param file_type: The type of file- for community uploads, these values are
+            either `community_csv` or `community_xlsx`
         """
 
         url = "%(ep)s/v0/%(tenant)s/temp" % {
             "ep": self.topic_api_url,
             "tenant": self.tenant,
         }
-        res = self._perform_request("get", url, params={"filename": filename})
+        res = self._perform_request(
+            "get", url, params={"filename": filename, "file_type": file_type}
+        )
         if res.status_code == 404:
             raise NotFoundError(res.status_code, "Not found")
         elif res.status_code != 200:
