@@ -1,7 +1,5 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import json
 from builtins import object
 
@@ -11,8 +9,9 @@ class ProjectGuideFilesMixin(object):
         """Creates a new Project Guide file.
 
         :param project_id: ID of the project.
-        :param guide_content:  Javascript content of the guide file as a
-            string.
+        :param guide_content: Javascript content of the guide file as a
+            string. The content is expected to be of type 'str', if guide_content
+            of type 'bytes' is passed, we try to decode it using 'utf-8'.
         """
         url = "/".join(
             [
@@ -27,6 +26,9 @@ class ProjectGuideFilesMixin(object):
 
         headers = {"Accept": "application/json", "Content-Type": "application/json"}
 
+        if isinstance(guide_content, bytes):
+            guide_content = guide_content.decode()
+
         data = {"data": {"guide_content": guide_content}}
         res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201])
