@@ -20,6 +20,7 @@ class ProjectsMixin(object):
             "guide_completed_steps",
             "theme",
             "integration_dashboards",
+            "first_visit",
         ]
     )
 
@@ -132,6 +133,7 @@ class ProjectsMixin(object):
         template_path=None,
         project_id=None,
         keep_ids=False,
+        import_app_nav_bar=True,
         import_dashboards=True,
         import_dashboard_widgets=True,
         import_dashboard_loaders=True,
@@ -140,6 +142,8 @@ class ProjectsMixin(object):
         import_enrichments=True,
         import_enrichment_pipelets=True,
         import_facets=True,
+        import_community_types=True,
+        import_communities=True,
         import_synonyms=True,
         import_machinelearning_workflows=True,
         import_machinelearning_jobs=True,
@@ -151,6 +155,7 @@ class ProjectsMixin(object):
         import_sources_dataloader_plugins=True,
         import_trends=True,
         import_items=True,
+        import_guide_file=True,
     ):
         """Create a new project from a project template.
 
@@ -174,6 +179,8 @@ class ProjectsMixin(object):
             project with the provided id. The length of the parameter must
             be 22 characters. Useful when exporting and importing projects
             across multiple Squirro servers.
+        :param import_app_nav_bar: Boolean. Whether to include the
+            app & nav bar. Defaults to `True`.
         :param keep_ids: Boolean. Whether to try to create entities
             (project_id, dashboards, sources) with the same ID as the original's project
         :param import_dashboards: Boolean. Whether to include the dashboards,
@@ -182,8 +189,8 @@ class ProjectsMixin(object):
             dashboards custom widgets. This only applies if `import_dashboards`
             is set to `True`. Defaults to `True`.
         :param import_dashboard_loaders: Boolean. Whether to include the
-            dashboards loaders. This only applies if `import_dashboards`
-            is set to `True`. Defaults to `True`.
+            dashboards loaders and dashboards themes. This only applies if
+            `import_dashboards` is set to `True`. Defaults to `True`.
         :param import_email_templates: Boolean. Whether to include the email
             templates. Defaults to `True`. NOT USED AT THE MOMENT
         :param import_pipeline_workflows: Boolean. Whether to include the
@@ -197,6 +204,10 @@ class ProjectsMixin(object):
         :param import_facets: Boolean. Whether to include the facets,
             defaults to `True`. Needs the `import_synonyms` to be set to `True`
             also.
+        :param import_community_types: Boolean. Whether to include the community_types,
+            defaults to `True`. Needs `import_facets` to be True.
+        :param import_communities: Boolean. Whether to include the communities,
+            defaults to `True`. Needs `import_community_types` to be True.
         :param import_synonyms: Boolean. Whether to include the synonyms lists,
             defaults to 'True'.
         :param import_machinelearning_workflows: Boolean. Whether to include
@@ -220,6 +231,8 @@ class ProjectsMixin(object):
         :param import_items: Boolean. Whether to include the items,
             defaults to `True`. Needs the `import_facets` to be set to `True`
             also.
+        :param import_guide_file: Boolean. Whether to include the project guide file,
+            defaults to `True`.
         :returns: A dictionary which contains the project identifier.
 
         Example::
@@ -251,6 +264,7 @@ class ProjectsMixin(object):
             data["keep_ids"] = True
 
         import_options = {
+            "import_app_nav_bar": import_app_nav_bar,
             "import_dashboards": import_dashboards,
             "import_dashboard_widgets": import_dashboard_widgets,
             "import_dashboard_loaders": import_dashboard_loaders,
@@ -258,6 +272,8 @@ class ProjectsMixin(object):
             "import_enrichments": import_enrichments,
             "import_enrichment_pipelets": import_enrichment_pipelets,
             "import_facets": import_facets,
+            "import_community_types": import_community_types,
+            "import_communities": import_communities,
             "import_machinelearning_workflows": import_machinelearning_workflows,
             "import_machinelearning_jobs": import_machinelearning_jobs,
             "import_machinelearning_models": import_machinelearning_models,
@@ -270,6 +286,7 @@ class ProjectsMixin(object):
             "import_trends": import_trends,
             "import_items": import_items,
             "import_synonyms": import_synonyms,
+            "import_guide_file": import_guide_file,
         }
         data["import_options"] = json.dumps(import_options)
 
@@ -391,6 +408,7 @@ class ProjectsMixin(object):
     def export_project(
         self,
         project_id,
+        export_app_nav_bar=True,
         export_dashboards=True,
         export_dashboard_widgets=True,
         export_dashboard_loaders=True,
@@ -399,6 +417,8 @@ class ProjectsMixin(object):
         export_enrichments=True,
         export_enrichment_pipelets=True,
         export_facets=True,
+        export_community_types=True,
+        export_communities=True,
         export_synonyms=True,
         export_machinelearning_workflows=True,
         export_machinelearning_jobs=True,
@@ -423,6 +443,8 @@ class ProjectsMixin(object):
             - enrichments
                 - optionally include pipelets
             - facets
+            - community_types
+            - communities
             - machinelearning workflow
                 - optionally include jobs
                 - optionally include models
@@ -447,13 +469,15 @@ class ProjectsMixin(object):
         as a parameter to get_project_export method to retrieve the zip archive
 
         :param project_id: Project identifier.
+        :param export_app_nav_bar: Boolean. Whether to include the
+            app & nav bar. Defaults to `True`.
         :param export_dashboards: Boolean. Whether to include the dashboards,
             defaults to `True`.
         :param export_dashboard_widgets: Boolean. Whether to include the
             dashboards custom widgets. This only applies if `export_dashboards`
             is set to `True`. Defaults to `True`.
         :param export_dashboard_loaders: Boolean. Whether to include the
-            dashboards loaders. This only applies if `export_dashboards`
+            dashboards loaders and dashboards themes. This only applies if `export_dashboards`
             is set to `True`. Defaults to `True`.
         :param export_email_templates: Boolean. Whether to include the email
             templates. Defaults to `True`.
@@ -465,9 +489,13 @@ class ProjectsMixin(object):
             pipelets together with the enrichments. This only applies of the
             `export_enrichments` is set to `True`. Defaults to `True`.
         :param export_facets: Boolean. Whether to include the facets,
-            defaults to `True`. Needs `export_synonyms` to be True
+            defaults to `True`. Needs `export_synonyms` to be True.
+        :param export_community_types: Boolean. Whether to include the community_types,
+            defaults to `True`. Needs `export_facets` to be True.
+        :param export_communities: Boolean. Whether to include the communities,
+            defaults to `True`. Needs `export_community_types` to be True.
         :param export_synonyms: Boolean. Whether to include the synonyms lists,
-            defaults to 'True'
+            defaults to 'True'.
         :param export_machinelearning_workflows: Boolean. Whether to include
             the machinelearning workflows. Defaults to `True`.
         :param export_machinelearning_jobs: Boolean. Whether to include the
@@ -511,6 +539,7 @@ class ProjectsMixin(object):
         headers = {"Content-Type": "application/json"}
 
         export_options = {
+            "export_app_nav_bar": export_app_nav_bar,
             "export_dashboards": export_dashboards,
             "export_dashboard_widgets": export_dashboard_widgets,
             "export_dashboard_loaders": export_dashboard_loaders,
@@ -518,6 +547,8 @@ class ProjectsMixin(object):
             "export_enrichments": export_enrichments,
             "export_enrichment_pipelets": export_enrichment_pipelets,
             "export_facets": export_facets,
+            "export_community_types": export_community_types,
+            "export_communities": export_communities,
             "export_machinelearning_workflows": export_machinelearning_workflows,
             "export_machinelearning_jobs": export_machinelearning_jobs,
             "export_machinelearning_models": export_machinelearning_models,
@@ -601,6 +632,7 @@ class ProjectsMixin(object):
         self,
         project_id,
         project_archive,
+        import_app_nav_bar=True,
         import_dashboards=True,
         import_dashboard_widgets=True,
         import_dashboard_loaders=True,
@@ -609,6 +641,8 @@ class ProjectsMixin(object):
         import_enrichments=True,
         import_enrichment_pipelets=True,
         import_facets=True,
+        import_community_types=True,
+        import_communities=True,
         import_synonyms=True,
         import_machinelearning_workflows=True,
         import_machinelearning_jobs=True,
@@ -620,6 +654,7 @@ class ProjectsMixin(object):
         import_sources_dataloader_plugins=True,
         import_trends=True,
         import_items=True,
+        import_guide_file=True,
     ):
 
         """Imports parts or all configuration and metadata of a project.
@@ -633,6 +668,8 @@ class ProjectsMixin(object):
             - enrichments
                 - optionally include pipelets
             - facets
+            - community_types
+            - communities
             - machinelearning workflow
                 - optionally include jobs
                 - optionally include models
@@ -654,13 +691,15 @@ class ProjectsMixin(object):
 
         :param project_id: Project identifier.
         :param project_archive: Path to project archive.
+        :param import_app_nav_bar: Boolean. Whether to include the
+            app & nav bar. Defaults to `True`.
         :param import_dashboards: Boolean. Whether to include the dashboards,
             defaults to `True`.
         :param import_dashboard_widgets: Boolean. Whether to include the
             dashboards custom widgets. This only applies if `import_dashboards`
             is set to `True`. Defaults to `True`.
         :param import_dashboard_loaders: Boolean. Whether to include the
-            dashboards loaders. This only applies if `import_dashboards`
+            dashboards loaders and dashboards themes. This only applies if `import_dashboards`
             is set to `True`. Defaults to `True`.
         :param import_email_templates: Boolean. Whether to include the email
             templates. Defaults to `True`.
@@ -674,6 +713,10 @@ class ProjectsMixin(object):
         :param import_facets: Boolean. Whether to include the facets,
             defaults to `True`. Needs the `import_synonyms` to be set to `True`
             also.
+        :param import_community_types: Boolean. Whether to include the community_types,
+            defaults to `True`. Needs `import_facets` to be True.
+        :param import_communities: Boolean. Whether to include the communities,
+            defaults to `True`. Needs `import_community_types` to be True.
         :param import_synonyms: Boolean. Whether to include the synonyms lists,
             defaults to 'True'.
         :param import_machinelearning_workflows: Boolean. Whether to include
@@ -697,6 +740,8 @@ class ProjectsMixin(object):
         :param import_items: Boolean. Whether to include the items,
             defaults to `True`. Needs the `import_facets` to be set to `True`
             also.
+        :param import_guide_file: Boolean. Whether to include the project guide file,
+            defaults to `True`.
         Example::
 
             >>> res = client.import_project(
@@ -714,6 +759,7 @@ class ProjectsMixin(object):
         headers = {"Content-Type": "application/json"}
 
         import_options = {
+            "import_app_nav_bar": import_app_nav_bar,
             "import_dashboards": import_dashboards,
             "import_dashboard_widgets": import_dashboard_widgets,
             "import_dashboard_loaders": import_dashboard_loaders,
@@ -721,6 +767,8 @@ class ProjectsMixin(object):
             "import_enrichments": import_enrichments,
             "import_enrichment_pipelets": import_enrichment_pipelets,
             "import_facets": import_facets,
+            "import_community_types": import_community_types,
+            "import_communities": import_communities,
             "import_machinelearning_workflows": import_machinelearning_workflows,
             "import_machinelearning_jobs": import_machinelearning_jobs,
             "import_machinelearning_models": import_machinelearning_models,
@@ -733,6 +781,7 @@ class ProjectsMixin(object):
             "import_trends": import_trends,
             "import_items": import_items,
             "import_synonyms": import_synonyms,
+            "import_guide_file": import_guide_file,
         }
         import_options["token"] = self.refresh_token
 
