@@ -1,15 +1,17 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
+
 import json
 from builtins import object
 
 
 class SourcesMixin(object):
-
-    def get_sources(self, project_id, include_config=None,
-                    include_run_stats=None, include_pipeline_backlog=None):
+    def get_sources(
+        self,
+        project_id,
+        include_config=None,
+        include_run_stats=None,
+        include_pipeline_backlog=None,
+    ):
         """Get all sources for the provided project.
 
         :param project_id: Project identifier.
@@ -72,26 +74,33 @@ class SourcesMixin(object):
             ]
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s'
-               '/sources')
+        url = "%(ep)s/%(version)s/%(tenant)s" "/projects/%(project_id)s" "/sources"
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
         params = {}
         if include_config:
-            params['include_config'] = include_config
+            params["include_config"] = include_config
         if include_run_stats:
-            params['include_run_stats'] = include_run_stats
+            params["include_run_stats"] = include_run_stats
         if include_pipeline_backlog:
-            params['include_pipeline_backlog'] = include_pipeline_backlog
+            params["include_pipeline_backlog"] = include_pipeline_backlog
 
-        res = self._perform_request('get', url, params=params)
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res)
 
-    def get_source(self, project_id, source_id, include_config=None,
-                   include_run_stats=None, include_pipeline_backlog=None):
+    def get_source(
+        self,
+        project_id,
+        source_id,
+        include_config=None,
+        include_run_stats=None,
+        include_pipeline_backlog=None,
+    ):
         """Get source details.
 
         :param project_id: Project identifier.
@@ -153,27 +162,41 @@ class SourcesMixin(object):
             }
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s'
-               '/sources/%(source_id)s')
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
 
         params = {}
         if include_config:
-            params['include_config'] = include_config
+            params["include_config"] = include_config
         if include_run_stats:
-            params['include_run_stats'] = include_run_stats
+            params["include_run_stats"] = include_run_stats
         if include_pipeline_backlog:
-            params['include_pipeline_backlog'] = include_pipeline_backlog
+            params["include_pipeline_backlog"] = include_pipeline_backlog
 
-        res = self._perform_request('get', url, params=params)
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res)
 
-    def new_source(self, project_id, name, config, scheduling_options,
-                   pipeline_workflow_id=None, source_id=None, paused=False):
+    def new_source(
+        self,
+        project_id,
+        name,
+        config,
+        scheduling_options=None,
+        pipeline_workflow_id=None,
+        source_id=None,
+        paused=False,
+        use_default_options=None,
+    ):
         """Create a new source.
 
         :param project_id: Project identifier.
@@ -191,6 +214,11 @@ class SourcesMixin(object):
             across multiple Squirro servers.
         :param paused: Optional boolean. Indicate whether to immediately start
             data loading, or rather create the source in a paused state
+        :param use_default_options: Optional boolean. Indicate whether or not to use
+            the default mappings for facets, fields, scheduling_options and pipeline
+            workflow provided by the dataloader plugin itself.
+            Setting this to `True` will throw a 400 HTTP error code if these default
+            mappings are not available for a specific plugin
         :returns: A dictionary which contains the new source.
 
         Example::
@@ -238,32 +266,38 @@ class SourcesMixin(object):
               "processed": false
             }
         """
-        headers = {'Content-Type': 'application/json'}
-        url = ('%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/sources')
+        headers = {"Content-Type": "application/json"}
+        url = "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/sources"
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
         # build data
-        data = {
-            'config': config,
-            'name': name,
-            'squirro_token': self.refresh_token,
-            'paused': paused
-        }
+        data = {"config": config, "name": name, "paused": paused}
         if source_id is not None:
-            data['source_id'] = source_id
+            data["source_id"] = source_id
         if pipeline_workflow_id is not None:
-            data['pipeline_workflow_id'] = pipeline_workflow_id
+            data["pipeline_workflow_id"] = pipeline_workflow_id
         if scheduling_options is not None:
-            data['scheduling_options'] = scheduling_options
+            data["scheduling_options"] = scheduling_options
+        if use_default_options is not None:
+            data["use_default_options"] = use_default_options
 
-        res = self._perform_request(
-            'post', url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [200, 201])
 
-    def modify_source(self, project_id, source_id, name=None, config=None,
-                      scheduling_options=None, pipeline_workflow_id=None):
+    def modify_source(
+        self,
+        project_id,
+        source_id,
+        name=None,
+        config=None,
+        scheduling_options=None,
+        pipeline_workflow_id=None,
+    ):
         """Modify an existing source.
 
         :param project_id: Project identifier.
@@ -299,27 +333,31 @@ class SourcesMixin(object):
 
         """
 
-        headers = {'Content-Type': 'application/json'}
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s/sources/%(source_id)s')
+        headers = {"Content-Type": "application/json"}
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s/sources/%(source_id)s"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
 
         # build data
         data = {}
         if name is not None:
-            data['name'] = name
+            data["name"] = name
         if config is not None:
-            data['config'] = config
+            data["config"] = config
         if scheduling_options is not None:
-            data['scheduling_options'] = scheduling_options
+            data["scheduling_options"] = scheduling_options
         if pipeline_workflow_id is not None:
-            data['pipeline_workflow_id'] = pipeline_workflow_id
+            data["pipeline_workflow_id"] = pipeline_workflow_id
 
-        res = self._perform_request(
-            'put', url, data=json.dumps(data), headers=headers)
+        res = self._perform_request("put", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [200])
 
     def delete_source(self, project_id, source_id):
@@ -335,17 +373,83 @@ class SourcesMixin(object):
 
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s'
-               '/sources/%(source_id)s')
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
 
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         self._process_response(res, [204])
 
+    def get_source_logs(self, project_id, source_id, last_n_log_lines):
+        """Get the run logs of a particular source run.
+
+        :param project_id: Project identifier.
+        :param source_id: Source identifier.
+        :param last_n_log_lines: Last n log lines from the last run of the source.
+
+        Example::
+
+            >>> client.get_source_logs('Vlg5Z1hOShm0eYmjtsqSqg',
+            ...                     'hw8j7LUBRM28-jAellgQdA',
+            ...                     10)
+        """
+
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s"
+            "/sources/%(source_id)s/logs"
+        )
+        url = url % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
+
+        params = {}
+        if last_n_log_lines:
+            params["last_n_log_lines"] = last_n_log_lines
+
+        res = self._perform_request("get", url, params=params)
+        return self._process_response(res)
+
+    def kill_source(self, project_id, source_id):
+        """Try to terminate (SIGTERM) a dataload job if it is already running. After a
+        fixed timeout, a SIGKILL signal is sent instead.
+
+        :param project_id: Project identifier.
+        :param source_id: Source identifier.
+
+        Example::
+
+            >>> client.kill_source('Vlg5Z1hOShm0eYmjtsqSqg',
+            ...                     'hw8j7LUBRM28-jAellgQdA')
+        """
+
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s"
+            "/sources/%(source_id)s/kill"
+        )
+        url = url % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
+
+        res = self._perform_request("post", url)
+        self._process_response(res, [200, 204])
+
     def pause_source(self, project_id, source_id):
         """Pause a source.
 
@@ -358,14 +462,19 @@ class SourcesMixin(object):
             ...                     'hw8j7LUBRM28-jAellgQdA')
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s'
-               '/sources/%(source_id)s/pause')
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s"
+            "/sources/%(source_id)s/pause"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
 
-        res = self._perform_request('put', url)
+        res = self._perform_request("put", url)
         self._process_response(res, [200, 204])
 
     def resume_source(self, project_id, source_id):
@@ -381,15 +490,20 @@ class SourcesMixin(object):
             ...     'hw8j7LUBRM28-jAellgQdA')
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s'
-               '/sources/%(source_id)s/resume')
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s/resume"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
 
-        res = self._perform_request('put', url)
+        res = self._perform_request("put", url)
         self._process_response(res, [200, 204])
 
     def run_source(self, project_id, source_id):
@@ -405,14 +519,19 @@ class SourcesMixin(object):
             ...     'hw8j7LUBRM28-jAellgQdA')
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s'
-               '/sources/%(source_id)s/run')
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s/run"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
-        res = self._perform_request('put', url)
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
+        res = self._perform_request("put", url)
         self._process_response(res, [200, 204])
 
     def reset_source(self, project_id, source_id, delete_source_data=None):
@@ -430,22 +549,88 @@ class SourcesMixin(object):
             ...     'hw8j7LUBRM28-jAellgQdA')
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/projects/%(project_id)s'
-               '/sources/%(source_id)s/reset')
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s/reset"
+        )
         url = url % {
-            'ep': self.topic_api_url, 'version': self.version,
-            'tenant': self.tenant, 'project_id': project_id,
-            'source_id': source_id}
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
         params = {}
 
         if delete_source_data:
-            params['delete_source_data'] = delete_source_data
+            params["delete_source_data"] = delete_source_data
 
-        res = self._perform_request('put', url, params=params)
+        res = self._perform_request("put", url, params=params)
+        self._process_response(res, [200, 204])
+
+    def get_max_inc(self, project_id, source_id):
+        """Fetches the maximum incremental value of a source.
+
+        :param project_id: Project identifier.
+        :param source_id: Source identifier.
+
+        Example::
+
+            >>> client.get_max_inc(
+            ...     'Vlg5Z1hOShm0eYmjtsqSqg',
+            ...     'hw8j7LUBRM28-jAellgQdA')
+        """
+
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s/max_inc_value"
+        )
+        url = url % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
+        res = self._perform_request("get", url)
+        return self._process_response(res)
+
+    def set_max_inc(self, project_id, source_id, max_inc_value):
+        """Sets the maximum incremental value of the incremental
+        column of a source.
+
+        :param project_id: Project identifier.
+        :param source_id: Source identifier.
+        :param max_inc_val: The maximum incremental value to be set.
+
+        Example::
+
+            >>> client.set_max_inc(
+            ...     'Vlg5Z1hOShm0eYmjtsqSqg',
+            ...     'hw8j7LUBRM28-jAellgQdA',
+            ...     '2020-08-17T19:10:33')
+        """
+
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s"
+            "/projects/%(project_id)s"
+            "/sources/%(source_id)s/max_inc_value"
+        )
+        url = url % {
+            "ep": self.topic_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "source_id": source_id,
+        }
+        data = {"data": {"max_inc_value": max_inc_value}}
+        res = self._perform_request("put", url, data=json.dumps(data))
         self._process_response(res, [200, 204])
 
     def get_preview(self, project_id, config):
+
         """Preview the source configuration.
 
         :param project_id: Project identifier.
@@ -488,13 +673,15 @@ class SourcesMixin(object):
             }
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/'
-               'preview') % {
-                   'ep': self.topic_api_url, 'project_id': project_id,
-                   'version': self.version, 'tenant': self.tenant}
+        url = ("%(ep)s/%(version)s/%(tenant)s/projects/%(project_id)s/" "preview") % {
+            "ep": self.topic_api_url,
+            "project_id": project_id,
+            "version": self.version,
+            "tenant": self.tenant,
+        }
 
         # build params
-        params = {'config': json.dumps(config)}
+        params = {"config": json.dumps(config)}
 
-        res = self._perform_request('get', url, params=params)
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res)
