@@ -11,11 +11,17 @@ from ..util import deprecation
 
 
 class TrendDetectionMixin(object):
-
-    def new_trenddetection(self, project_id, name, query, email_user,
-                           aggregation_interval, aggregation_field=None,
-                           aggregation_method=None,
-                           aggregation_time_field=None):
+    def new_trenddetection(
+        self,
+        project_id,
+        name,
+        query,
+        email_user,
+        aggregation_interval,
+        aggregation_field=None,
+        aggregation_method=None,
+        aggregation_time_field=None,
+    ):
         """Create a new trend detection.
 
         :param project_id: Id of the project.
@@ -72,20 +78,22 @@ class TrendDetectionMixin(object):
             }
         """
         url = self._get_trenddetection_base_url() % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
+        data = {
+            "query": query,
+            "name": name,
+            "email_user": email_user,
+            "aggregation_interval": aggregation_interval,
+            "aggregation_field": aggregation_field,
+            "aggregation_method": aggregation_method,
+            "aggregation_time_field": aggregation_time_field,
         }
-        data = {'query': query, 'name': name, 'email_user': email_user,
-                'aggregation_interval': aggregation_interval,
-                'aggregation_field': aggregation_field,
-                'aggregation_method': aggregation_method,
-                'aggregation_time_field': aggregation_time_field}
 
-        headers = {
-            'Accept': 'application/json', 'Content-Type': 'application/json'}
-        res = self._perform_request(
-            'post', url, data=json.dumps(data), headers=headers)
+        headers = {"Accept": "application/json", "Content-Type": "application/json"}
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def modify_trenddetection(self, project_id, trenddetection_id, **kwargs):
@@ -109,15 +117,15 @@ class TrendDetectionMixin(object):
         params = dict([(k, v) for k, v in kwargs.items() if v is not None])
 
         url = self._get_trenddetection_base_url(trenddetection_id) % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
-            'trenddetection_id': trenddetection_id
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "trenddetection_id": trenddetection_id,
         }
-        headers = {
-            'Accept': 'application/json', 'Content-Type': 'application/json'}
+        headers = {"Accept": "application/json", "Content-Type": "application/json"}
         res = self._perform_request(
-            'put', url, data=json.dumps(params), headers=headers)
+            "put", url, data=json.dumps(params), headers=headers
+        )
         return self._process_response(res, [204])
 
     def get_trenddetections(self, project_id):
@@ -147,20 +155,26 @@ class TrendDetectionMixin(object):
                 }
         """
         url = self._get_trenddetection_base_url() % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
         }
 
-        headers = {'Accept': 'application/json'}
-        res = self._perform_request('get', url, headers=headers)
+        headers = {"Accept": "application/json"}
+        res = self._perform_request("get", url, headers=headers)
         return self._process_response(res)
 
-    def get_trenddetection(self, project_id, trenddetection_id,
-                           include_trend_detection_entity=None,
-                           include_thresholds=None, include_anomalies=None,
-                           include_predictions=None, result_before=None,
-                           result_after=None):
+    def get_trenddetection(
+        self,
+        project_id,
+        trenddetection_id,
+        include_trend_detection_entity=None,
+        include_thresholds=None,
+        include_anomalies=None,
+        include_predictions=None,
+        result_before=None,
+        result_after=None,
+    ):
         """Get details for a particular trend detection entity.
 
         :param project_id: Id of the project.
@@ -217,26 +231,26 @@ class TrendDetectionMixin(object):
         # also
         # prepare url
         url = self._get_trenddetection_base_url(trenddetection_id) % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
-            'trenddetection_id': trenddetection_id,
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "trenddetection_id": trenddetection_id,
         }
 
         # prepare params
         params = {
-            'include_trend_detection_entity': include_trend_detection_entity,
-            'include_thresholds': include_thresholds,
-            'include_anomalies': include_anomalies,
-            'include_predictions': include_predictions,
-            'result_after': result_after,
-            'result_before': result_before
+            "include_trend_detection_entity": include_trend_detection_entity,
+            "include_thresholds": include_thresholds,
+            "include_anomalies": include_anomalies,
+            "include_predictions": include_predictions,
+            "result_after": result_after,
+            "result_before": result_before,
         }
 
         params = dict([(k, v) for k, v in params.items() if v is not None])
 
-        headers = {'Accept': 'application/json'}
-        res = self._perform_request('get', url, params=params, headers=headers)
+        headers = {"Accept": "application/json"}
+        res = self._perform_request("get", url, params=params, headers=headers)
         return self._process_response(res)
 
     def delete_trenddetection(self, project_id, trenddetection_id):
@@ -252,24 +266,29 @@ class TrendDetectionMixin(object):
             ...     trenddetection_id='fd5x9NIqQbyBmF4Yph9MMw')
         """
         url = self._get_trenddetection_base_url(trenddetection_id) % {
-            'ep': self.topic_api_url,
-            'tenant': self.tenant,
-            'project_id': project_id,
-            'trenddetection_id': trenddetection_id,
+            "ep": self.topic_api_url,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "trenddetection_id": trenddetection_id,
         }
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
     # TODO: deprecate this method in lieu of `get_trenddetection` method. Also,
     # be aware of the difference in defaults of `get_trenddetection` method as
     # compared to `get_trenddetection_result` method.
-    def get_trenddetection_result(self, project_id, trenddetection_id,
-                                  result_before=None, result_after=None,
-                                  include_thresholds=True,
-                                  include_anomalies=True,
-                                  include_historical_data=True,
-                                  include_trend_detection_entity=True,
-                                  include_predictions=False):
+    def get_trenddetection_result(
+        self,
+        project_id,
+        trenddetection_id,
+        result_before=None,
+        result_after=None,
+        include_thresholds=True,
+        include_anomalies=True,
+        include_historical_data=True,
+        include_trend_detection_entity=True,
+        include_predictions=False,
+    ):
         """
         DEPRECATED. Please use the `get_trenddetection` method instead.
 
@@ -358,22 +377,29 @@ class TrendDetectionMixin(object):
                 }
         """
         deprecation(
-            'This method will be removed with release 2.5.3. Please use the '
-            '`get_trenddetection` method instead.')
+            "This method will be removed with release 2.5.3. Please use the "
+            "`get_trenddetection` method instead."
+        )
 
         # UTC -- time format
         # TODO: Remove this hardcoded time-format once the trends-service start
         # storing the historical data also as this will not be needed anymore
-        time_format = '%Y-%m-%dT%H:%M:%S'
+        time_format = "%Y-%m-%dT%H:%M:%S"
 
         # get trend-detection and all it's relevant parameters except the
         # historical data
         include_thresholds_for_historical_data = True
         include_tde_for_historical_data = True
         ret = self.get_trenddetection(
-            project_id, trenddetection_id, include_tde_for_historical_data,
-            include_thresholds_for_historical_data, include_anomalies,
-            include_predictions, result_before, result_after)
+            project_id,
+            trenddetection_id,
+            include_tde_for_historical_data,
+            include_thresholds_for_historical_data,
+            include_anomalies,
+            include_predictions,
+            result_before,
+            result_after,
+        )
 
         # TODO: remove the logic for getting the historical data once the
         # trends-service store the historical data itself
@@ -382,85 +408,92 @@ class TrendDetectionMixin(object):
         if include_historical_data:
 
             # return empty historical data if we get back no thresholds data
-            if len(ret['thresholds']) < 2:
-                ret['historical_values'] = {'values': []}
+            if len(ret["thresholds"]) < 2:
+                ret["historical_values"] = {"values": []}
 
             else:
-                interval = (datetime.strptime(ret['thresholds'][1].
-                                              get('timestamp'), time_format) -
-                            datetime.strptime(
-                                ret['thresholds'][0].get('timestamp'),
-                                time_format)).total_seconds()
+                interval = (
+                    datetime.strptime(
+                        ret["thresholds"][1].get("timestamp"), time_format
+                    )
+                    - datetime.strptime(
+                        ret["thresholds"][0].get("timestamp"), time_format
+                    )
+                ).total_seconds()
 
-                historical_data_first_bucket = ret['thresholds'][0].get(
-                    'timestamp')
-                historical_data_last_bucket = (
-                    datetime.strptime(ret['thresholds'][-1].get('timestamp'),
-                                      time_format) +
-                    timedelta(seconds=interval - 1))
-                historical_data_last_bucket = (
-                    historical_data_last_bucket.strftime(time_format))
+                historical_data_first_bucket = ret["thresholds"][0].get("timestamp")
+                historical_data_last_bucket = datetime.strptime(
+                    ret["thresholds"][-1].get("timestamp"), time_format
+                ) + timedelta(seconds=interval - 1)
+                historical_data_last_bucket = historical_data_last_bucket.strftime(
+                    time_format
+                )
 
                 # prepare params for fetching historical data
-                time_field = (ret['trend_detection_entity'].
-                              get('aggregation_time_field'))
+                time_field = ret["trend_detection_entity"].get("aggregation_time_field")
                 if not time_field:
-                    time_field = '$item_created_at'
+                    time_field = "$item_created_at"
 
                 aggregation = {
-                    'trend_detection_values': {
-                        'fields': [time_field],
-                        'interval': ret['trend_detection_entity'].get(
-                            'aggregation_interval'),
-                        'method': 'histogram',
-                        'min_doc_count': 0
+                    "trend_detection_values": {
+                        "fields": [time_field],
+                        "interval": ret["trend_detection_entity"].get(
+                            "aggregation_interval"
+                        ),
+                        "method": "histogram",
+                        "min_doc_count": 0,
                     }
                 }
 
-                aggregation_field = (ret['trend_detection_entity'].
-                                     get('aggregation_field'))
-                aggregation_method = (ret['trend_detection_entity'].
-                                      get('aggregation_method'))
+                aggregation_field = ret["trend_detection_entity"].get(
+                    "aggregation_field"
+                )
+                aggregation_method = ret["trend_detection_entity"].get(
+                    "aggregation_method"
+                )
                 if aggregation_field and aggregation_method:
                     innerAggregation = {
-                        'fields': [aggregation_field],
-                        'method': aggregation_method
+                        "fields": [aggregation_field],
+                        "method": aggregation_method,
                     }
-                    aggregation['trend_detection_values']['aggregation'] = (
-                        innerAggregation)
+                    aggregation["trend_detection_values"][
+                        "aggregation"
+                    ] = innerAggregation
 
                 # query
                 aggs = self.query(
-                    project_id, query=ret['trend_detection_entity'].
-                    get('query'),
-                    aggregations=aggregation, count=0,
+                    project_id,
+                    query=ret["trend_detection_entity"].get("query"),
+                    aggregations=aggregation,
+                    count=0,
                     created_before=historical_data_last_bucket,
-                    created_after=historical_data_first_bucket)
-                aggs = aggs.get('aggregations', {})
+                    created_after=historical_data_first_bucket,
+                )
+                aggs = aggs.get("aggregations", {})
 
-                tds_aggs = aggs.get(
-                    'trend_detection_values', {}).get(time_field)
-                ret['historical_values'] = tds_aggs
+                tds_aggs = aggs.get("trend_detection_values", {}).get(time_field)
+                ret["historical_values"] = tds_aggs
 
                 if not tds_aggs:
                     raise ValueError(
-                        'Could not retrieve trend detection historical values')
+                        "Could not retrieve trend detection historical values"
+                    )
 
         # remove thresholds and tde parameters if not requested originally
         if not include_thresholds:
-            del ret['thresholds']
+            del ret["thresholds"]
 
         if not include_trend_detection_entity:
-            del ret['trend_detection_entity']
+            del ret["trend_detection_entity"]
 
         return ret
 
     def _get_trenddetection_base_url(self, trenddetection_id=None):
         """Returns the URL template for a trend detection. """
-        parts = ['%(ep)s/v0/%(tenant)s']
-        parts.append('/projects/%(project_id)s/trenddetections')
+        parts = ["%(ep)s/v0/%(tenant)s"]
+        parts.append("/projects/%(project_id)s/trenddetections")
 
         if trenddetection_id:
-            parts.append('/%(trenddetection_id)s')
+            parts.append("/%(trenddetection_id)s")
 
-        return ''.join(parts)
+        return "".join(parts)
