@@ -1,9 +1,3 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
-from future import standard_library
-
 import base64
 import io
 import json
@@ -14,8 +8,6 @@ from builtins import object, str
 
 import hjson
 
-standard_library.install_aliases()  # noqa
-
 
 class WidgetsAndAssetsMixin(object):
 
