@@ -18,7 +18,7 @@ class UserApiMixin(object):
     {TOC}
     """
 
-    def get_user_data(self, user_id, api_version='v1'):
+    def get_user_data(self, user_id, api_version="v1"):
         """Return data about a specific user, including any custom values.
 
         :param user_id: User identifier.
@@ -34,13 +34,16 @@ class UserApiMixin(object):
 
         """
 
-        url = '%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s' % {
-            'endpoint': self.user_api_url, 'version': api_version,
-            'tenant': self.tenant, 'user': user_id}
-        res = self._perform_request('get', url)
+        url = "%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s" % {
+            "endpoint": self.user_api_url,
+            "version": api_version,
+            "tenant": self.tenant,
+            "user": user_id,
+        }
+        res = self._perform_request("get", url)
         return self._process_response(res)
 
-    def update_user_data(self, user_id, changes, api_version='v1'):
+    def update_user_data(self, user_id, changes, api_version="v1"):
         """Update data for the given user. Any value can be set and will be
         returned again when getting the user.
 
@@ -60,17 +63,21 @@ class UserApiMixin(object):
 
         """
 
-        url = '%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s' % {
-            'endpoint': self.user_api_url, 'version': api_version,
-            'tenant': self.tenant, 'user': user_id}
+        url = "%(endpoint)s/%(version)s/%(tenant)s/users/%(user)s" % {
+            "endpoint": self.user_api_url,
+            "version": api_version,
+            "tenant": self.tenant,
+            "user": user_id,
+        }
 
-        if api_version == 'v1':
-            headers = {'Content-Type': 'application/json'}
+        if api_version == "v1":
+            headers = {"Content-Type": "application/json"}
             res = self._perform_request(
-                'put', url, data=json.dumps(changes), headers=headers)
+                "put", url, data=json.dumps(changes), headers=headers
+            )
 
         else:
-            res = self._perform_request('put', url, data=changes)
+            res = self._perform_request("put", url, data=changes)
 
         return self._process_response(res)
 
@@ -93,21 +100,30 @@ class UserApiMixin(object):
              u'state': u'ok'}
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/authentications/%(service)s/%(user_id)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'service': service,
-                   'user_id': user_id
-               }
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s" "/authentications/%(service)s/%(user_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "service": service,
+            "user_id": user_id,
+        }
 
-        res = self._perform_request('get', url)
+        res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
-    def new_or_modify_authentication(self, user_id, service, service_user,
-                                     access_token, access_secret=None,
-                                     display_name=None,
-                                     access_token_expires=None,
-                                     access_secret_expires=None):
+    def new_or_modify_authentication(
+        self,
+        user_id,
+        service,
+        service_user,
+        access_token,
+        access_secret=None,
+        display_name=None,
+        access_token_expires=None,
+        access_secret_expires=None,
+    ):
         """Create a new authentication or modify an existing authentication
         for an external service.
 
@@ -137,37 +153,35 @@ class UserApiMixin(object):
              u'state': u'ok'}
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/authentications/%(service)s/%(user_id)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'service': service, 'user_id': user_id
-               }
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s" "/authentications/%(service)s/%(user_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "service": service,
+            "user_id": user_id,
+        }
 
         # build data
-        data = {
-            'service_user': service_user, 'access_token': access_token
-        }
+        data = {"service_user": service_user, "access_token": access_token}
         if display_name is not None:
-            data['display_name'] = display_name
+            data["display_name"] = display_name
         if access_secret is not None:
-            data['access_secret'] = access_secret
+            data["access_secret"] = access_secret
         if access_token_expires is not None:
-            data['access_token_expires'] = self._format_date(
-                access_token_expires)
+            data["access_token_expires"] = self._format_date(access_token_expires)
         if access_secret_expires is not None:
-            data['access_secret_expires'] = self._format_date(
-                access_secret_expires)
+            data["access_secret_expires"] = self._format_date(access_secret_expires)
 
         # build params
-        params = {
-            'client_id': self.client_id, 'client_secret': self.client_secret
-        }
+        params = {"client_id": self.client_id, "client_secret": self.client_secret}
 
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
 
         res = self._perform_request(
-            'post', url, params=params, data=json.dumps(data),
-            headers=headers)
+            "post", url, params=params, data=json.dumps(data), headers=headers
+        )
         return self._process_response(res, [200, 201])
 
     def delete_authentication(self, user_id, service):
@@ -182,18 +196,20 @@ class UserApiMixin(object):
             ...                              'facebook')
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/authentications/%(service)s/%(user_id)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'service': service,
-                   'user_id': user_id
-               }
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s" "/authentications/%(service)s/%(user_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "service": service,
+            "user_id": user_id,
+        }
 
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
-    def new_grant(self, user_id, type, for_client_id=None,
-                  project_permissions=None):
+    def new_grant(self, user_id, type, for_client_id=None, project_permissions=None):
         """Create a new grant.
 
         :param user_id: User identifier.
@@ -213,25 +229,29 @@ class UserApiMixin(object):
              u'refresh_token': u'b4c7440364afb80c2...14e2d538b0b773894ea2'}
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/users/%(user)s/grants' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'user': user_id}
+        url = "%(ep)s/%(version)s/%(tenant)s/users/%(user)s/grants" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "user": user_id,
+        }
 
         params = {
-            'type': type, 'client_id': self.client_id,
-            'client_secret': self.client_secret
+            "type": type,
+            "client_id": self.client_id,
+            "client_secret": self.client_secret,
         }
 
         # If the type is session we need to pass the target
-        if type == 'service':
-            params['for_client_id'] = for_client_id
+        if type == "service":
+            params["for_client_id"] = for_client_id
 
         if project_permissions:
             if isinstance(project_permissions, list):
-                project_permissions = ','.join(project_permissions)
-            params['project_permissions'] = project_permissions
+                project_permissions = ",".join(project_permissions)
+            params["project_permissions"] = project_permissions
 
-        res = self._perform_request('post', url, data=params)
+        res = self._perform_request("post", url, data=params)
         return self._process_response(res, [201])
 
     def delete_grant(self, user_id, grant_id):
@@ -263,15 +283,16 @@ class UserApiMixin(object):
                           u'id': u'yL0dnd17RNe9Jpn7uAa8Bw', u'type': u'user'}]}
         """
 
-        url = '%(ep)s/%(version)s/%(tenant)s/users/%(user)s/grants' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'user': user_id}
-
-        params = {
-            'client_id': self.client_id, 'client_secret': self.client_secret
+        url = "%(ep)s/%(version)s/%(tenant)s/users/%(user)s/grants" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "user": user_id,
         }
 
-        res = self._perform_request('get', url, params=params)
+        params = {"client_id": self.client_id, "client_secret": self.client_secret}
+
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res, [200])
 
     def delete_session(self, user_id, session_id):
@@ -286,14 +307,17 @@ class UserApiMixin(object):
             ...                       'yL0dnd17RNe9Jpn7uAa8Bw')
         """
 
-        url = ('%(ep)s/%(version)s/%(tenant)s'
-               '/users/%(user)s/sessions/%(session_id)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'user': user_id,
-                   'session_id': session_id
-               }
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s" "/users/%(user)s/sessions/%(session_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "user": user_id,
+            "session_id": session_id,
+        }
 
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
     def get_users(self, include_config=None):
@@ -319,14 +343,15 @@ class UserApiMixin(object):
         """
         params = {}
         if include_config is not None:
-            params['include_config'] = include_config
+            params["include_config"] = include_config
 
-        url = '%(ep)s/%(version)s/%(tenant)s/users' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant
+        url = "%(ep)s/%(version)s/%(tenant)s/users" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
         }
 
-        res = self._perform_request('get', url, params=params)
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res, [200])
 
     def add_user(self, email=None, password=None, role=None):
@@ -338,24 +363,23 @@ class UserApiMixin(object):
         :param role: role of the user in the tenant. Must be one of:
             admin, user, demo, reader
         """
-        headers = {'Content-Type': 'application/json'}
+        headers = {"Content-Type": "application/json"}
         data = {}
 
         email_regex = re.compile(r"[^@]+@[^@]+\.[^@]+")
         if email and email_regex.match(email):
-            data['email'] = email
+            data["email"] = email
         if password:
-            data['password'] = password
+            data["password"] = password
         if role:
-            data['role'] = role
+            data["role"] = role
 
-        url = '%(ep)s/v0/%(tenant)s/users' % {
-            'ep': self.user_api_url, 'tenant': self.tenant
+        url = "%(ep)s/v0/%(tenant)s/users" % {
+            "ep": self.user_api_url,
+            "tenant": self.tenant,
         }
-        
-        res = self._perform_request('post', url,
-                                    data=json.dumps(data),
-                                    headers=headers)
+
+        res = self._perform_request("post", url, data=json.dumps(data), headers=headers)
         return self._process_response(res, [201])
 
     def delete_user(self, user_id):
@@ -367,11 +391,13 @@ class UserApiMixin(object):
 
             >>> client.delete_user('H5Qv-WhgSBGW0WL8xolSCQ')
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/users/%(user_id)s' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'user_id': user_id,
+        url = "%(ep)s/%(version)s/%(tenant)s/users/%(user_id)s" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "user_id": user_id,
         }
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
     def get_project_members(self, project_id):
@@ -406,17 +432,17 @@ class UserApiMixin(object):
         has in this project. The permissions depend on the user's project role
         and server role.
         """
-        url = ('%(ep)s/%(version)s/%(tenant)s/'
-               'projects/%(project_id)s/members') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'project_id': project_id
-               }
+        url = ("%(ep)s/%(version)s/%(tenant)s/" "projects/%(project_id)s/members") % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+        }
 
-        res = self._perform_request('get', url)
+        res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
-    def add_project_member(self, project_id, role, user_id=None,
-                           group_id=None):
+    def add_project_member(self, project_id, role, user_id=None, group_id=None):
         """Adds a user or group to a project as a member.
 
         :param project_id: Project identifier of the project in which to add
@@ -451,18 +477,15 @@ class UserApiMixin(object):
                                 u'sources.*']
             }
         """
-        url = ('%(ep)s/%(version)s/%(tenant)s/'
-               'projects/%(project_id)s/members') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'project_id': project_id
-               }
-
-        data = {
-            'user_id': user_id,
-            'group_id': group_id,
-            'role': role,
+        url = ("%(ep)s/%(version)s/%(tenant)s/" "projects/%(project_id)s/members") % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
         }
-        res = self._perform_request('post', url, data=data)
+
+        data = {"user_id": user_id, "group_id": group_id, "role": role}
+        res = self._perform_request("post", url, data=data)
         return self._process_response(res, [200])
 
     def update_project_member(self, project_id, member_id, role):
@@ -489,13 +512,17 @@ class UserApiMixin(object):
                …
             }
         """
-        url = ('%(ep)s/%(version)s/%(tenant)s/'
-               'projects/%(project_id)s/members/%(member_id)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'project_id': project_id,
-                   'member_id': member_id,
-               }
-        res = self._perform_request('put', url, data={'role': role})
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s/"
+            "projects/%(project_id)s/members/%(member_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "member_id": member_id,
+        }
+        res = self._perform_request("put", url, data={"role": role})
         return self._process_response(res)
 
     def delete_project_member(self, project_id, member_id):
@@ -510,13 +537,17 @@ class UserApiMixin(object):
             >>> client.delete_project_member('2sic33jZTi-ifflvQAVcfw',
                                              'H5Qv-WhgSBGW0WL8xolSCQ')
         """
-        url = ('%(ep)s/%(version)s/%(tenant)s/'
-               'projects/%(project_id)s/members/%(member_id)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'project_id': project_id,
-                   'member_id': member_id,
-               }
-        res = self._perform_request('delete', url)
+        url = (
+            "%(ep)s/%(version)s/%(tenant)s/"
+            "projects/%(project_id)s/members/%(member_id)s"
+        ) % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "project_id": project_id,
+            "member_id": member_id,
+        }
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
     def get_groups(self):
@@ -540,10 +571,12 @@ class UserApiMixin(object):
              }
             ]
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/groups' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant}
-        res = self._perform_request('get', url)
+        url = "%(ep)s/%(version)s/%(tenant)s/groups" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+        }
+        res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
     def create_group(self, name):
@@ -560,11 +593,12 @@ class UserApiMixin(object):
                 u'members': []
             }
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/groups' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant,
+        url = "%(ep)s/%(version)s/%(tenant)s/groups" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
         }
-        res = self._perform_request('post', url, data={'name': name})
+        res = self._perform_request("post", url, data={"name": name})
         return self._process_response(res, [201])
 
     def get_group(self, group_id):
@@ -591,10 +625,13 @@ class UserApiMixin(object):
                 ]
             }
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/groups/%(group)s' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'group': group_id}
-        res = self._perform_request('get', url)
+        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "group": group_id,
+        }
+        res = self._perform_request("get", url)
         return self._process_response(res, [200])
 
     def update_group(self, group_id, name):
@@ -621,10 +658,13 @@ class UserApiMixin(object):
                 ]
             }
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/groups/%(group)s' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'group': group_id}
-        res = self._perform_request('put', url, data={'name': name})
+        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "group": group_id,
+        }
+        res = self._perform_request("put", url, data={"name": name})
         return self._process_response(res, [200])
 
     def delete_group(self, group_id):
@@ -636,11 +676,13 @@ class UserApiMixin(object):
 
             >>> client.delete_group('1jo-WmmyRvC8UYtPMIQaoQ')
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/groups/%(group)s' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'group': group_id
+        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "group": group_id,
         }
-        res = self._perform_request('delete', url)
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
 
     def add_group_member(self, group_id, user_id):
@@ -662,11 +704,13 @@ class UserApiMixin(object):
                 u'tenant': 'lW8-FnZlQYWBimxFknYitw'
             }
         """
-        url = '%(ep)s/%(version)s/%(tenant)s/groups/%(group)s' % {
-            'ep': self.user_api_url, 'version': self.version,
-            'tenant': self.tenant, 'group': group_id
+        url = "%(ep)s/%(version)s/%(tenant)s/groups/%(group)s" % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "group": group_id,
         }
-        res = self._perform_request('post', url, data={'user_id': user_id})
+        res = self._perform_request("post", url, data={"user_id": user_id})
         return self._process_response(res, [200])
 
     def delete_group_member(self, group_id, user_id):
@@ -680,10 +724,12 @@ class UserApiMixin(object):
             >>> client.delete_group_member('1jo-WmmyRvC8UYtPMIQaoQ',
                                            'H5Qv-WhgSBGW0WL8xolSCQ')
         """
-        url = ('%(ep)s/%(version)s/%(tenant)s/'
-               'groups/%(group)s/members/%(user)s') % {
-                   'ep': self.user_api_url, 'version': self.version,
-                   'tenant': self.tenant, 'group': group_id, 'user': user_id
-               }
-        res = self._perform_request('delete', url)
+        url = ("%(ep)s/%(version)s/%(tenant)s/" "groups/%(group)s/members/%(user)s") % {
+            "ep": self.user_api_url,
+            "version": self.version,
+            "tenant": self.tenant,
+            "group": group_id,
+            "user": user_id,
+        }
+        res = self._perform_request("delete", url)
         return self._process_response(res, [204])
